@@ -1,12 +1,12 @@
 import functools
 import typing
 
-import export
+import expo
 
 from . import models
 from . import types
 
-@export
+@expo
 def generate_next_value(func: typing.Callable[[models.Arguments], typing.Any]) -> types.EnumValueGenerator:
     @functools.wraps(func)
     def wrapper(name: str, start: int, count: int, last_values: typing.List[typing.Any]) -> typing.Any:
@@ -23,12 +23,12 @@ def generate_next_value(func: typing.Callable[[models.Arguments], typing.Any]) -
 
     return wrapper
 
-@export
+@expo
 @generate_next_value
 def name(arguments: models.Arguments) -> str:
     return arguments.name
 
-@export
+@expo
 @generate_next_value
 def count(arguments: models.Arguments) -> int:
     return arguments.count
